@@ -303,9 +303,9 @@ class App:
                 set_vars.append('%s=%s' % (key, value))
         cmd = ['univention-app', 'configure', '%s=%s' % (self.app_name, self.app_version)]
         if set_vars:
-            cmd.extend(['--set'] + set_vars)
+            cmd.extend(['--set', *set_vars])
         if unset_vars:
-            cmd.extend(['--unset'] + unset_vars)
+            cmd.extend(['--unset', *unset_vars])
         error_handling_call(cmd, exc=UCSTest_DockerApp_ConfigureFailed)
 
     def install_via_umc(self):
@@ -492,8 +492,9 @@ class Appcenter:
             self.add_ucs_version_to_appcenter('4.4')
             self.add_ucs_version_to_appcenter('5.0')
             self.add_ucs_version_to_appcenter('5.1')
-            self.versions = ['4.4', '5.0', '5.1']
-            self._write_ucs_ini('[5.1]\nSupportedUCSVersions=5.1, 5.0, 4.4\n[5.0]\nSupportedUCSVersions=5.0, 4.4, 4.3\n[4.4]\nSupportedUCSVersions=4.4, 4.3, 4.2, 4.1\n[4.3]\nSupportedUCSVersions=4.3, 4.2, 4.1\n')
+            self.add_ucs_version_to_appcenter('5.2')
+            self.versions = ['4.4', '5.0', '5.1', '5.2']
+            self._write_ucs_ini('[5.2]\nSupportedUCSVersions=5.2, 5.1, 5.0, 4.4\n[5.1]\nSupportedUCSVersions=5.1, 5.0, 4.4\n[5.0]\nSupportedUCSVersions=5.0, 4.4, 4.3\n[4.4]\nSupportedUCSVersions=4.4, 4.3, 4.2, 4.1\n[4.3]\nSupportedUCSVersions=4.3, 4.2, 4.1\n')
             self._write_suggestions_json()
         else:
             self.add_ucs_version_to_appcenter(version)
