@@ -36,26 +36,34 @@ import json
 import os
 import socket
 from types import SimpleNamespace
-from typing import Any, Callable, Dict, Generator, Iterator
+from typing import TYPE_CHECKING, Any
+from urllib.parse import urlparse
 
 import pytest
 from keycloak import KeycloakAdmin, KeycloakOpenID
 from playwright.sync_api import Browser, BrowserContext, Page, expect
 from utils import (
-    get_portal_tile, grant_oidc_privileges, keycloak_login, keycloak_password_change, legacy_auth_config_create,
-    legacy_auth_config_remove, run_command,
+    get_language_code, get_portal_tile, grant_oidc_privileges, keycloak_login, keycloak_password_change,
+    legacy_auth_config_create, legacy_auth_config_remove, run_command,
 )
 
 from univention.appcenter.actions import get_action
 from univention.appcenter.app_cache import Apps
-from univention.config_registry import ConfigRegistry
+from univention.config_registry import ConfigRegistry, handler_set, handler_unset
 from univention.lib.misc import custom_groupname
 from univention.testing.pytest_univention_playwright import fixtures
 from univention.testing.udm import UCSTestUDM
-from univention.testing.utils import UCSTestDomainAdminCredentials, get_ldap_connection, wait_for_listener_replication
+from univention.testing.utils import (
+    UCSTestDomainAdminCredentials, get_ldap_connection, wait_for_listener_replication, wait_for_s4connector_replication,
+)
 from univention.udm import UDM
 from univention.udm.binary_props import Base64Bzip2BinaryProperty
-from univention.udm.modules.settings_data import SettingsDataObject
+
+
+if TYPE_CHECKING:
+    from collections.abc import Callable, Generator, Iterator
+
+    from univention.udm.modules.settings_data import SettingsDataObject
 
 
 # don't use the ucs-test ucr fixture (UCSTestConfigRegistry)
@@ -83,13 +91,19 @@ def keycloak_secret() -> str | None:
     return password
 
 
-@pytest.fixture(autouse=True)
-def is_keycloak(request, keycloak_config, ucr_proper):
-    if request.node.get_closest_marker('is_keycloak'):
-        keycloak_ip = socket.gethostbyname(keycloak_config.server)
-        my_ip = socket.gethostbyname(ucr_proper['hostname'])
-        if keycloak_ip != my_ip:
-            pytest.skip('this system is not the keycloak server, test makes no sense here')
+# make sure we are the keycloak server, useful for tests that change local configuration
+# and expect a certain behavior in keycloak
+@pytest.fixture()
+def is_keycloak(keycloak_config, ucr_proper):
+    keycloak_ip = socket.gethostbyname(keycloak_config.server)
+    my_ip = socket.gethostbyname(ucr_proper['hostname'])
+    if keycloak_ip != my_ip:
+        pytest.skip('this system is not the keycloak server, test makes no sense here')
+    try:
+        handler_set([f'hosts/static/{my_ip}={keycloak_config.server}'])
+        yield True
+    finally:
+        handler_unset([f'hosts/static/{my_ip}'])
 
 
 @pytest.fixture()
@@ -108,13 +122,6 @@ def keycloak_settings() -> dict:
     return settings
 
 
-@pytest.fixture()
-def keycloak_app_version() -> str:
-    apps_cache = Apps()
-    version = [app.version for app in apps_cache.get_all_locally_installed_apps() if app.id == 'keycloak']
-    return version[0]
-
-
 @pytest.fixture()
 def tracing_page(page, request: pytest.FixtureRequest, ucr_proper):
     page.context.tracing.start(screenshots=True, snapshots=True)
@@ -124,32 +131,6 @@ def tracing_page(page, request: pytest.FixtureRequest, ucr_proper):
     fixtures.teardown_umc_browser_test(request, ucr_proper, page, page.context, page.context.browser)
 
 
-@pytest.fixture()
-def change_app_setting():
-    data = {'app': None, 'configure': None, 'changes': {}}
-
-    def _func(app_id: str, changes: dict, revert: bool = True) -> None:
-        apps_cache = Apps()
-        app = apps_cache.find(app_id, latest=True)
-        data['app'] = app
-        configure = get_action('configure')
-        data['configure'] = configure
-        settings = configure.list_config(app)
-        known_settings = {x.get('name'): x.get('value') for x in settings}
-        for change in changes:
-            if change in known_settings:
-                if revert:
-                    data['changes'][change] = known_settings[change]
-            else:
-                raise Exception(f'Unknown setting: {change}')
-        configure.call(app=app, set_vars=changes)
-
-    yield _func
-
-    if data['changes']:
-        data['configure'].call(app=data['app'], set_vars=data['changes'])
-
-
 @pytest.fixture()
 def upgrade_status_obj(ucr_proper) -> SettingsDataObject:
     udm = UDM.admin().version(2)
@@ -163,13 +144,13 @@ def upgrade_status_obj(ucr_proper) -> SettingsDataObject:
     obj.save()
 
 
-class UnverfiedUser(object):
+class UnverfiedUser:
     def __init__(self, udm: UCSTestUDM, password: str = 'univention'):
         self.ldap = get_ldap_connection(primary=True)
         self.password = password
         self.dn, self.username = udm.create_user(password=password)
         changes = [
-            ('objectClass', [b''], self.ldap.get(self.dn).get('objectClass') + [b'univentionPasswordSelfService']),
+            ('objectClass', [b''], [*self.ldap.get(self.dn).get('objectClass'), b'univentionPasswordSelfService']),
             ('univentionPasswordSelfServiceEmail', [''], [b'root@localhost']),
             ('univentionPasswordRecoveryEmailVerified', [''], [b'FALSE']),
             ('univentionRegisteredThroughSelfService', [''], [b'TRUE']),
@@ -213,8 +194,6 @@ def portal_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
         'password': 'univention',
         'header_menu_id': 'header-button-menu',
         'portal_sidenavigation_username_class': 'portal-sidenavigation--username',
-        'logout_msg': 'Logout',
-        'logout_msg_de': 'Abmelden',
         'logout_button_id': 'loginButton',
     }
 
@@ -223,13 +202,14 @@ def portal_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
 
 @pytest.fixture()
 def keycloak_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
-    server = ucr_proper.get('keycloak/server/sso/fqdn', f"ucs-sso-ng.{ucr_proper['domainname']}")
-    path = ucr_proper['keycloak/server/sso/path'] if ucr_proper['keycloak/server/sso/path'] else ''
-    url = f'https://{server}{path}'
+    url = run_command(['univention-keycloak', 'get-keycloak-base-url']).rstrip()
+    server = urlparse(url).netloc
+    path = urlparse(url).path
+    password = ucr_proper['tests/domainadmin/pwd']
     config = {
         'server': server,
         'path': path,
-        'url': url,
+        'url': os.path.join(url, ''),  # we need a trailing / here, see keycloak apache proxy config
         'admin_url': f'{url}/admin',
         'token_url': f'{url}/realms/ucs/protocol/openid-connect/token',
         'logout_url': f'{url}/realms/ucs/protocol/openid-connect/logout',
@@ -244,7 +224,7 @@ def keycloak_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
         'login_data': {
             'client_id': 'admin-cli',
             'username': 'Administrator',
-            'password': 'univention',
+            'password': f'{password}',
             'grant_type': 'password',
         },
         'logout_all_data': {'realm': 'ucs'},
@@ -253,23 +233,19 @@ def keycloak_config(ucr_proper: ConfigRegistry) -> SimpleNamespace:
         'password_id': 'password',
         'login_error_css_selector': "span[class='pf-c-alert__title kc-feedback-text']",
         'password_update_error_css_selector': "span[class='pf-c-alert__title kc-feedback-text']",
-        'wrong_password_msg': 'Invalid username or password.',
-        'wrong_password_msg_de': 'Ungültiger Benutzername oder Passwort.',
         'kc_passwd_update_form_id': 'kc-passwd-update-form',
         'password_confirm_id': 'password-confirm',
         'password_new_id': 'password-new',
         'password_change_button_id': 'kc-form-buttons',
-        'password_update_failed_msg': 'Update password failed',
         'kc_page_title_id': 'kc-page-title',
-        'account_expired_msg': 'The account has expired.',
-        'account_disabled_msg': 'The account is disabled.',
     }
     return SimpleNamespace(**config)
 
 
 @pytest.fixture(scope='session')
 def browser_context_args(browser_context_args):
-    return {**browser_context_args, 'ignore_https_errors': True}
+    expect.set_options(timeout=30 * 1000)
+    return {**browser_context_args, 'ignore_https_errors': True, 'locale': get_language_code()}
 
 
 @pytest.fixture(scope='session')
@@ -297,33 +273,26 @@ def __portal_login_func(
     no_login: bool = False,
     protocol: str | None = 'saml',
 ):
-    try:
-        url = url or portal_config.url
-        page.goto(url)
-        expect(page).to_have_title(portal_config.title)
-        lang = page.evaluate('() => window.navigator.userLanguage || window.navigator.language')
-        sso_login_tile = portal_config.sso_login_tile if lang == 'en-US' else portal_config.sso_login_tile_de
-        if protocol == 'oidc':
-            sso_login_tile = portal_config.sso_oidc_login_tile
-        get_portal_tile(page, sso_login_tile, portal_config).click()
-        # login
-        keycloak_login(page, keycloak_config, username, password, fails_with=fails_with if not new_password else None, no_login=no_login)
-        # check password change
-        if new_password:
-            new_password_confirm = new_password_confirm or new_password
-            keycloak_password_change(page, keycloak_config, username, password, new_password, new_password_confirm, fails_with=fails_with)
-        if protocol == 'oidc':
-            grant_oidc_privileges(page)
-        if fails_with or no_login:
-            return page
-        # check that we are logged in
-        if verify_login:
-            header_menu = page.locator(f'#{portal_config.header_menu_id}')
-            expect(header_menu, 'header menu not visible').to_be_visible()
+    url = url or portal_config.url
+    page.goto(url)
+    expect(page).to_have_title(portal_config.title)
+    sso_login_tile = portal_config.sso_oidc_login_tile if protocol == 'oidc' else portal_config.sso_login_tile
+    get_portal_tile(page, sso_login_tile, portal_config).click()
+    # login
+    keycloak_login(page, keycloak_config, username, password, fails_with=fails_with if not new_password else None, no_login=no_login)
+    # check password change
+    if new_password:
+        new_password_confirm = new_password_confirm if new_password_confirm else new_password
+        keycloak_password_change(page, keycloak_config, username, password, new_password, new_password_confirm, fails_with=fails_with)
+    if protocol == 'oidc':
+        grant_oidc_privileges(page)
+    if fails_with or no_login:
         return page
-    except Exception:
-        print(page.content())
-        raise
+    # check that we are logged in
+    if verify_login:
+        header_menu = page.locator(f'#{portal_config.header_menu_id}')
+        expect(header_menu, 'header menu not visible').to_be_visible()
+    return page
 
 
 @pytest.fixture()
@@ -347,19 +316,14 @@ def keycloak_adm_login(tracing_page: Page, keycloak_config: SimpleNamespace):
         url: str | None = keycloak_config.url,
         no_login: bool = False,
     ):
-        try:
-            page.goto(url)
-            page.wait_for_load_state('networkidle', timeout=5 * 1000)
-            print(page.content())
-            expect(page).to_have_title('Univention Corporate Server Single-Sign On', timeout=30 * 1000)
-            keycloak_login(page, keycloak_config, username, password, fails_with=fails_with, no_login=no_login)
-            # check that we are logged in
-            if fails_with or no_login:
-                return page
-            expect(page).to_have_title('Keycloak Administration Console')
-        except Exception:
-            print(page.content())
-            raise
+        page.goto(url)
+        page.wait_for_load_state('networkidle', timeout=5 * 1000)
+        expect(page).to_have_title('Univention Corporate Server Single-Sign On', timeout=30 * 1000)
+        keycloak_login(page, keycloak_config, username, password, fails_with=fails_with, no_login=no_login)
+        # check that we are logged in
+        if fails_with or no_login:
+            return page
+        expect(page).to_have_title('Keycloak Administration Console')
         return page
 
     return _func
@@ -466,7 +430,7 @@ def legacy_authorization_setup_oidc(
     client = f'testclient-{user_name}'
     client_secret = 'abc'
     groups = {group_name: client}
-
+    wait_for_s4connector_replication()
     try:
         # create flow
         run_command(['univention-keycloak', 'legacy-authentication-flow', 'create', '--flow', 'direct grant'])
@@ -500,7 +464,7 @@ def legacy_authorization_setup_oidc(
 
 @pytest.fixture()
 def modify_keycloak_clients(request):
-    mod_func: Callable[[Dict[Any, Any]]] = request.param
+    mod_func: Callable[[dict[Any, Any]]] = request.param
     modified_clients = []
     oidc_clients = json.loads(run_command(['univention-keycloak', 'oidc/rp', 'get', '--json', '--all']))
 
