@@ -30,12 +30,54 @@
 
 from __future__ import annotations
 
+import locale
 import subprocess
-from types import SimpleNamespace
+from typing import TYPE_CHECKING
 
 import requests
-from keycloak import KeycloakAdmin
+from bs4 import BeautifulSoup
 from playwright.sync_api import Page, expect
+from requests_kerberos import OPTIONAL, HTTPKerberosAuth
+
+from univention.testing.utils import wait_for_listener_replication_and_postrun
+
+
+if TYPE_CHECKING:
+    from types import SimpleNamespace
+
+    from keycloak import KeycloakAdmin
+
+
+TRANSLATIONS = {
+    'de-DE': {
+        'Username': 'Benutzername',
+        'Password': 'Passwort',
+        'Username or email': 'Benutzername oder E-Mail',
+        'password': 'Passwort',
+        'Sign In': 'Anmelden',
+        'Invalid username or password.': 'Ungültiger Benutzername oder Passwort.',
+        'Login (Single sign-on)': 'Anmelden (Single Sign-on)',
+        'Changing password failed. The password was already used.': 'Passwort ändern fehlgeschlagen. Das Passwort wurde bereits genutzt.',
+        'Changing password failed. The password is too short.': 'Passwort ändern fehlgeschlagen. Das Passwort ist zu kurz.',
+        'Changing password failed. The password is too short. The password must consist of at least 8 characters.': 'Passwort ändern fehlgeschlagen. Das Passwort ist zu kurz. Das Passwort muss mindestens 8 Zeichen lang sein.',
+        'Changing password failed. The password was already used. Choose a password which does not match any of your last 3 passwords.': 'Passwort ändern fehlgeschlagen. Das Passwort wurde bereits genutzt. Wählen Sie ein Passwort, dass nicht den letzten 3 Passwörtern entspricht.',
+        "Passwords don't match.": 'Passwörter sind nicht identisch.',
+        'Please specify password.': 'Bitte geben Sie ein Passwort ein.',
+        'LOGOUT': 'ABMELDEN',
+        'Unexpected error when handling authentication request to identity provider.': 'Unerwarteter Fehler während der Bearbeitung der Anfrage an den Identity Provider.',
+        'The account has expired.': 'Das Benutzerkonto ist abgelaufen.',
+        'The account is disabled.': 'Das Benutzerkonto ist deaktiviert.',
+        'en-US text': 'de-DE text',
+        'en-US title': 'de-DE title',
+        'ACCEPT': 'ANNEHMEN',
+        'Accept': 'Annehmen',
+        'en yada yada yada': 'de yada yada yada',
+        'Your account is not verified.': 'Konto nicht verifiziert.',
+        'Access forbidden.': 'Zugriff verboten.',
+        'Menu': 'Menü',
+        'Login': 'Anmelden',
+    },
+}
 
 
 def host_is_alive(host: str) -> bool:
@@ -44,12 +86,17 @@ def host_is_alive(host: str) -> bool:
 
 
 def get_portal_tile(page: Page, text: str, portal_config: SimpleNamespace):
-    return page.get_by_label(text)
+    return page.get_by_label(_(text))
+
+
+def get_language_code() -> str:
+    return locale.getlocale()[0].replace('_', '-')
 
 
 def keycloak_password_change(
     page: Page,
     keycloak_config: SimpleNamespace,
+    username: str,
     password: str,
     new_password: str,
     new_password_confirm: str,
@@ -62,7 +109,12 @@ def keycloak_password_change(
 
     if fails_with:
         error = page.locator(keycloak_config.password_update_error_css_selector.replace("[class='", ".").replace("']", "").replace(" ", "."))
-        assert fails_with == error.inner_text(), f'{fails_with} != {error.inner_text()}'
+        assert _(fails_with) == error.inner_text(), f'{fails_with} != {error.inner_text()}'
+        return
+
+    wait_for_listener_replication_and_postrun()
+    if (page.get_by_label(_("Username or email")).is_visible()):
+        keycloak_login(page=page, username=username, password=new_password, keycloak_config=keycloak_config)
 
 
 def keycloak_auth_header(config: SimpleNamespace) -> dict:
@@ -74,6 +126,12 @@ def keycloak_auth_header(config: SimpleNamespace) -> dict:
     }
 
 
+def keycloak_post_request(config: SimpleNamespace, path: str, params: dict | None = None) -> dict:
+    response = requests.post(f'{config.admin_url}/{path}', headers=keycloak_auth_header(config), params=params)
+    assert response.status_code == 200, response.text
+    return response.json()
+
+
 def keycloak_get_request(config: SimpleNamespace, path: str, params: dict | None = None) -> dict:
     response = requests.get(f'{config.admin_url}/{path}', headers=keycloak_auth_header(config), params=params)
     assert response.status_code == 200, response.text
@@ -100,6 +158,14 @@ def keycloak_sessions_by_user(config: SimpleNamespace, username: str) -> dict:
     return response.json()
 
 
+def _(string: str) -> str:
+    lc = get_language_code()
+    if lc in TRANSLATIONS:
+        return TRANSLATIONS[lc].get(string, string)
+    else:
+        return string
+
+
 def keycloak_delete_session(config: SimpleNamespace, session_id: str) -> None:
     url = f'{config.sessions_url}/{session_id}'
     response = requests.delete(url, headers=keycloak_auth_header(config))
@@ -129,17 +195,24 @@ def keycloak_login(
     fails_with: str | None = None,
     no_login: bool = False,
 ) -> None:
-    name = page.get_by_label("Username or email")
-    expect(name, "login form username input not visible").to_be_visible()
-    pw = page.get_by_label("password")
-    expect(pw, "password form input not visible").to_be_visible()
+    try:
+        name = page.get_by_label(_("Username or email"))
+        expect(name, "login form username input not visible").to_be_visible()
+        pw = page.get_by_label(_("password"))
+        expect(pw, "password form input not visible").to_be_visible()
+        if no_login:
+            return
+        name.fill(username)
+        pw.fill(password)
+        page.get_by_role("button", name=_("Sign In")).click()
+        if fails_with:
+            error = page.locator(keycloak_config.login_error_css_selector)
+            assert _(fails_with) == error.inner_text(), f'{_(fails_with)} == {error.inner_text()}'
+            assert error.is_visible()
 
-    if no_login:
-        return
-
-    name.fill(username)
-    pw.fill(password)
-    page.get_by_role("button", name="Sign In").click()
+    except Exception:
+        print(page.content())
+        raise
 
 
 def run_command(cmd: list) -> str:
@@ -147,6 +220,50 @@ def run_command(cmd: list) -> str:
     return subprocess.run(cmd, stdout=subprocess.PIPE, check=True).stdout.decode('utf-8')
 
 
+def kerberos_auth(portal_login_via_keycloak, ucr, protocol, portal_config):
+    if protocol == 'oidc':
+        # login with playwright to get rid of the oidc grant
+        # privileges dialog, i don't get it to work with requests
+        #   soup = BeautifulSoup(page.content, features='lxml')
+        #   uri = soup.find('form', {'class': 'form-actions'}).attrs['action']
+        #   code = soup.find('input', {'name': 'code'}).attrs['value']
+        #   data = {'code': code, 'accept': 'Yes'}
+        #   page = session.post(f'https://ucs-sso-ng.ucs.test/{uri}', data=data, verify='/etc/univention/ssl/ucsCA/CAcert.pem', headers=headers)
+        page = portal_login_via_keycloak('Administrator', 'univention', protocol='oidc')
+        portal_logout(page, portal_config)
+        page.close()
+
+    ucr.handler_set(['kerberos/defaults/rdns=false'])
+    subprocess.call(['kdestroy'])
+    subprocess.check_call(['kinit', '--password-file=/var/lib/ucs-test/pwdfile', 'Administrator'])
+    session = requests.Session()
+    session.auth = HTTPKerberosAuth(mutual_authentication=OPTIONAL)
+
+    headers = {'Accept-Language': 'en-US;q=0.6,en;q=0.4', 'Referer': ''}
+    url = f'https://{portal_config.fqdn}/univention/saml/' if protocol == 'saml' else f'https://{portal_config.fqdn}/univention/oidc/'
+    page = session.get(url, data=None, verify='/etc/univention/ssl/ucsCA/CAcert.pem', headers=headers)
+    assert page.status_code == 200
+
+    if protocol == 'saml':
+        soup = BeautifulSoup(page.content, features='lxml')
+        saml_resp = soup.find('input', {'name': 'SAMLResponse'}).attrs['value']
+        relay_state = soup.find('input', {'name': 'RelayState'}).attrs['value']
+        uri = soup.find('form', {'name': 'saml-post-binding'}).attrs['action']
+        print(f'Got URI: {uri}')
+        print(f'Got SAMLResponse: {saml_resp}')
+        print(f'Got RelayState: {relay_state}')
+        assert saml_resp
+        data = {'SAMLResponse': saml_resp, 'RelayState': relay_state}
+        page = session.post(uri, data=data, verify='/etc/univention/ssl/ucsCA/CAcert.pem', headers=headers)
+        assert page.status_code == 200
+
+    cookies = session.cookies.get_dict()
+    assert cookies['UMCUsername'] == 'Administrator'
+    assert 'UMCSessionId' in cookies
+    assert 'AUTH_SESSION_ID' in cookies
+    assert 'KEYCLOAK_IDENTITY' in cookies
+
+
 def legacy_auth_config_remove(session: KeycloakAdmin, groups: dict) -> None:
     """
     groups = {
