@@ -55,8 +55,8 @@ def login_via_oidc(client, username=None, password=None, prefix=''):
     login_params.update(
         {
             'username': username,
-            'password': password
-        }
+            'password': password,
+        },
     )
 
     with client.post(login_link, data=login_params, name=f'{prefix} oidc login 2 POST credentials', catch_response=True, timeout=TIMEOUT) as req3:
@@ -93,7 +93,7 @@ def login_via_saml(client, username=None, password=None, prefix=''):
         {
             'username': username,
             'password': password,
-        }
+        },
     )
 
     with client.post(login_link, data=login_params, name=f'{prefix} login 2 POST credentials', catch_response=True, timeout=TIMEOUT) as req3:
