@@ -46,13 +46,16 @@ file.
 from __future__ import annotations
 
 import copy
-from types import TracebackType
-from typing import Any, Dict, Type
+from typing import TYPE_CHECKING, Any
 
 import univention.config_registry
 from univention.config_registry import ConfigRegistry
 
 
+if TYPE_CHECKING:
+    from types import TracebackType
+
+
 class UCSTestConfigRegistry(ConfigRegistry):
     """
     Extension to ConfigRegistry to be able to clean up after
@@ -62,7 +65,7 @@ class UCSTestConfigRegistry(ConfigRegistry):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         """initialise object"""
         ConfigRegistry.__init__(self, *args, **kwargs)
-        self.__original_registry: Dict[int, Dict[str, str]] | None = None
+        self.__original_registry: dict[int, dict[str, str]] | None = None
 
     def ucr_update(self, *args):
         return univention.config_registry.frontend.ucr_update(*args)
@@ -113,7 +116,7 @@ class UCSTestConfigRegistry(ConfigRegistry):
         self.load()
         return self
 
-    def __exit__(self, exc_type: Type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
+    def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         self.revert_to_original_registry()
 
 
