@@ -33,13 +33,17 @@ from __future__ import annotations
 
 import subprocess
 import sys
-from typing import Iterable, Mapping, Sequence
+from typing import TYPE_CHECKING
 
 from univention.config_registry import ConfigRegistry
 from univention.testing.strings import random_name, random_version
 from univention.testing.utils import fail, get_ldap_connection
 
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable, Mapping, Sequence
+
+
 VALID_EXTENSION_TYPES = ('hook', 'syntax', 'module')
 
 
